function y = dslegend(l,m,x)
%DSLEGEND Derivative of associated Legendre function with Schmidt
%        semi-normalization.
%   P = DSLEGEND(L,M,X) computes the derivative with respect to x of the
%   associated Legendre function with Schmidt semi-normalization of
%   degree L and order M evaluated for each element of X.
%   L and M must be a scalar integer and X must contain real values
%   between -1 <= X <= 1.  

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 05 december 2022
% Program distributed under the GNU Lesser General Public License (LGPL)


y=zeros(size(x));
m=abs(m); % For the Schmidt semi-normalization, values for m and -m are the same
% Case when the order exceeds the degree
if m>l 
    return; % return zero values
end

% Computation of the derivative for the positive order
if m~=0
   cste=-sqrt((l+m+1)*(l-m));
else
   cste=-sqrt(l*(l+1)/2);
end
for i=1:length(x)
    if abs(x(i))<1
       y1=-(1./sqrt(1-x^2))*cste.*slegend(l,m+1,x);
       y2=(m*x./(x^2-1)).*slegend(l,m,x);
       y(i)=y1+y2;
    else
        y(i)=0;
    end
end

end%of function

