function y = slegend(l,m,x)
%SLEGEND Associated Legendre function with Schmidt semi-normalization.
%   P = SLEGEND(L,M,X) computes the associated Legendre function 
%   of degree N and order M with the Schmidt semi-normalization 
%   evaluated for each element of X.
%   N must be a scalar integer and X must contain real values
%   between -1 <= X <= 1.  

% Author: Stephane BALAC, IRMAR, CNRS, University of Rennes, France
% contact: stephane.balac@univ-rennes1.fr
% Last modification: 05 december 2022
% Program distributed under the GNU Lesser General Public License (LGPL)

y=zeros(size(x));
m=abs(m); % For the Schmidt semi-normalization, values for m and -m are the same
% Case when the order exceeds the degree
if m>l
    return; % return zero values
end
% Compute the associated Legendre functions of degree N and order
% M = 0, 1, ..., N, evaluated for each element of X.
Y=legendre(l,x,'sch');
% Extract the associated Legendre function of degree N and order M
y=Y(m+1,:);

end%of function

